@@ -19,11 +19,12 @@ library(VGAM)
 # retinopathy$SM <- as.factor(retinopathy$SM)
 
 ## ----results='hide'---------------------------------------
-pom <- vglm(RET ~ SM + DIAB + GH + BP, family = cumulative(parallel=TRUE), 
-            data = retinopathy)
+pom <- vglm(RET ~ SM + DIAB + GH + BP, 
+            family = cumulative(parallel=TRUE), data = retinopathy)
 
 ## ----results='hide'---------------------------------------
-ppom <- vglm(RET ~ SM + DIAB + GH + BP, family = cumulative(parallel=FALSE), 
+ppom <- vglm(RET ~ SM + DIAB + GH + BP, 
+             family = cumulative(parallel=FALSE), 
              data = retinopathy)
 
 ## ---------------------------------------------------------
